==> zio-aws-nimble_2.12-5.17.295.16-sources.jar: zio/aws/nimble/model/StartStudioSsoConfigurationRepairRequest.scala <==
package zio.aws.nimble.model
import zio.aws.nimble.model.primitives.ClientToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class StartStudioSsoConfigurationRepairRequest(
    clientToken: Optional[ClientToken] = Optional.Absent,
    studioId: String
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.nimble.model.StartStudioSsoConfigurationRepairRequest = {
    import StartStudioSsoConfigurationRepairRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.nimble.model.StartStudioSsoConfigurationRepairRequest
      .builder()
      .optionallyWith(
        clientToken.map(value => ClientToken.unwrap(value): java.lang.String)
      )(_.clientToken)
      .studioId(studioId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.nimble.model.StartStudioSsoConfigurationRepairRequest.ReadOnly =
    zio.aws.nimble.model.StartStudioSsoConfigurationRepairRequest
      .wrap(buildAwsValue())
}
object StartStudioSsoConfigurationRepairRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.nimble.model.StartStudioSsoConfigurationRepairRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.nimble.model.StartStudioSsoConfigurationRepairRequest =
      zio.aws.nimble.model.StartStudioSsoConfigurationRepairRequest(
        clientToken.map(value => value),
        studioId
      )
    def clientToken: Optional[ClientToken]
    def studioId: String
    def getClientToken: ZIO[Any, AwsError, ClientToken] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getStudioId: ZIO[Any, Nothing, String] = ZIO.succeed(studioId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.nimble.model.StartStudioSsoConfigurationRepairRequest
  ) extends zio.aws.nimble.model.StartStudioSsoConfigurationRepairRequest.ReadOnly {
    override val clientToken: Optional[ClientToken] = zio.aws.core.internal
      .optionalFromNullable(impl.clientToken())
      .map(value => zio.aws.nimble.model.primitives.ClientToken(value))
    override val studioId: String = impl.studioId(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.nimble.model.StartStudioSsoConfigurationRepairRequest
  ): zio.aws.nimble.model.StartStudioSsoConfigurationRepairRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-nimble_2.13-5.17.150.1-sources.jar: zio/aws/nimble/model/StartStudioSsoConfigurationRepairRequest.scala <==
package zio.aws.nimble.model
import zio.aws.nimble.model.primitives.ClientToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class StartStudioSsoConfigurationRepairRequest(
    clientToken: Option[ClientToken] = None,
    studioId: String
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.nimble.model.StartStudioSsoConfigurationRepairRequest = {
    import StartStudioSsoConfigurationRepairRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.nimble.model.StartStudioSsoConfigurationRepairRequest
      .builder()
      .optionallyWith(
        clientToken.map(value => ClientToken.unwrap(value): java.lang.String)
      )(_.clientToken)
      .studioId(studioId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.nimble.model.StartStudioSsoConfigurationRepairRequest.ReadOnly =
    zio.aws.nimble.model.StartStudioSsoConfigurationRepairRequest
      .wrap(buildAwsValue())
}
object StartStudioSsoConfigurationRepairRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.nimble.model.StartStudioSsoConfigurationRepairRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.nimble.model.StartStudioSsoConfigurationRepairRequest =
      zio.aws.nimble.model.StartStudioSsoConfigurationRepairRequest(
        clientToken.map(value => value),
        studioId
      )
    def clientToken: Option[ClientToken]
    def studioId: String
    def getClientToken: ZIO[Any, AwsError, ClientToken] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getStudioId: ZIO[Any, Nothing, String] = ZIO.succeed(studioId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.nimble.model.StartStudioSsoConfigurationRepairRequest
  ) extends zio.aws.nimble.model.StartStudioSsoConfigurationRepairRequest.ReadOnly {
    override val clientToken: Option[ClientToken] = scala
      .Option(impl.clientToken())
      .map(value => zio.aws.nimble.model.primitives.ClientToken(value))
    override val studioId: String = impl.studioId(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.nimble.model.StartStudioSsoConfigurationRepairRequest
  ): zio.aws.nimble.model.StartStudioSsoConfigurationRepairRequest.ReadOnly =
    new Wrapper(impl)
}
